@@ -1,5 +1,5 @@
 package Linux::Systemd::Journal::Write;
-$Linux::Systemd::Journal::Write::VERSION = '0.002';
+$Linux::Systemd::Journal::Write::VERSION = '0.003';
 # ABSTRACT: XS wrapper around sd-journal
 
 # TODO Helper script to generate message catalogs?
@@ -36,7 +36,7 @@ has priority => (
 
 sub print {
     my ($self, $msg, $pri) = @_;
-    $pri = $self->priority if !$pri;
+    $pri //= $self->priority;
     __sd_journal_print($pri, $msg);
     return 1;
 }
@@ -120,7 +120,7 @@ Linux::Systemd::Journal::Write - XS wrapper around sd-journal
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
